@@ -6,19 +6,14 @@ import tiny_listener
 
 
 def show_version(ctx, _, value) -> None:
-    if not value or ctx.resilient_parsing:
-        return
-    click.echo(f"tiny-listener {tiny_listener.__version__}")
-    ctx.exit()
+    if value and not ctx.resilient_parsing:
+        click.echo(f"tiny-listener {tiny_listener.__version__}")
+        ctx.exit()
 
 
 @click.command()
 @click.option(
-    "--app-dir",
-    "app_dir",
-    default=".",
-    show_default=True,
-    help="Your APP directory.",
+    "--app-dir", "app_dir", default=".", show_default=True, help="Your APP directory."
 )
 @click.option(
     "--version",
@@ -28,7 +23,7 @@ def show_version(ctx, _, value) -> None:
     is_eager=True,
     help="Display version info.",
 )
-@click.argument('app')
+@click.argument("app")
 def main(app_dir, app):
     sys.path.insert(0, app_dir)
     try:
